.. _utils.filtering:

Signal Filtering
================

.. automodule:: eyetrace.utils.filtering
   :members:
   :undoc-members:
   :show-inheritance:

Filtering utilities for smoothing and denoising time series data.
Includes moving average, Savitzky‑Golay filter, and a simple 1D Kalman
filter.